pub trait ModelContext {
type Context;
// Required method
fn context() -> Self::Context;
}Expand description
Represents a source of context for models.
Models can retrieve context from an implementor of this trait.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl ModelContext for ()
Placeholder type for models that do not require any external context.
impl ModelContext for ()
Placeholder type for models that do not require any external context.